# EnvironmentStatus

The status of an appliction environment. This can be used to determine how an application instance is running, if it needs any maintenence, or if an upgrade is in progress 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**runtime_status** | [**RuntimeStatus**](RuntimeStatus.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


